from fastapi import APIRouter, HTTPException, status
from schemas.contact_form import ContactFormCreate
from helpers.contact_form_helpers import create_contact_form, validate_email
from fastapi import Depends
from sqlalchemy.orm import Session
from core.database import get_db

router = APIRouter()

@router.post("/form", status_code=status.HTTP_201_CREATED, response_model=ContactFormCreate)
async def create_form(
    contact_form_data: ContactFormCreate,
    db: Session = Depends(get_db)
):
    if not validate_email(contact_form_data.email):
        raise HTTPException(status_code=400, detail="Invalid email format")

    new_contact_form = create_contact_form(db=db, contact_form_data=contact_form_data)
    return new_contact_form